@@ -4,7 +4,6 @@
 #------------------------------------------------------------------------------
 
 
-if(interactive()) library(testthat)
 sampleRoot <- system.file("sampledata", package = "sss")
 filenameSSS <- file.path(sampleRoot, "sample-3.sss")
 filenameASC <- file.path(sampleRoot, "sample-3.dat")
@@ -14,11 +13,12 @@ file.exists(filenameASC)
 
 #------------------------------------------------------------------------------
 
-context("sample 3")
+
 
 test_that("parsing of .sss and .asc works", {
-  test <- read.sss(filenameSSS, filenameASC)
-  expect_is(test, "data.frame")
-  expect_equal(nrow(test), 694)
+  test <- 
+    read.sss(filenameSSS, filenameASC)
+  expect_s3_class(test,  "data.frame")
+  expect_equal(nrow(test), 98)
   expect_equal(ncol(test), 200)
 })
